@@ -19,12 +19,16 @@
 
 /**
  * SECTION:gstnetaddressmeta
+ * @title: GstNetAddressMeta
  * @short_description: Network address metadata
  *
  * #GstNetAddressMeta can be used to store a network address (a #GSocketAddress)
  * in a #GstBuffer so that it network elements can track the to and from address
  * of the buffer.
  */
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
 
 #include <string.h>
 
@@ -68,7 +72,7 @@ net_address_meta_free (GstMeta * meta, GstBuffer * buffer)
 GType
 gst_net_address_meta_api_get_type (void)
 {
-  static volatile GType type;
+  static GType type;
   static const gchar *tags[] = { "origin", NULL };
 
   if (g_once_init_enter (&type)) {
